"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.httpDigestAuth = void 0;
const swish_node_digest_auth_1 = require("@juriskop/swish-node-digest-auth");
const configKey = 'httpDigestAuth';
const storedKey = 'storedDigestValues';
const httpDigestAuth = (axiosInstance, credentials) => {
    axiosInstance.interceptors.request.use((request) => {
        if (request[configKey] && request[configKey][storedKey]) {
            const storedValues = request[configKey][storedKey];
            if (!request.url || !storedValues.realm || !request.method || !storedValues.nonce || !storedValues.cnonce || !request.headers) {
                throw new Error('Axios HTTP Digest Auth: Unexpected state reached.');
            }
            const digestRelevantPath = new URL(request.url).pathname;
            const ha1 = (0, swish_node_digest_auth_1.generateHA1)(credentials.username, storedValues.realm, credentials.password);
            const ha2 = (0, swish_node_digest_auth_1.generateHA2)(request.method.toUpperCase(), digestRelevantPath);
            const response = (0, swish_node_digest_auth_1.generateResponse)(ha1, ha2, storedValues.nonce, storedValues.nonceCounter, storedValues.cnonce, storedValues.qop);
            const paddedNonceCounter = storedValues.nonceCounter.toString(10).padStart(8, '0');
            request.headers['Authorization'] = `Digest username="${credentials.username}", realm="${storedValues.realm}", nonce="${storedValues.nonce}", uri="${digestRelevantPath}", algorithm="MD5", qop=${storedValues.qop}, nc=${paddedNonceCounter}, cnonce=${storedValues.cnonce}, response="${response}"`;
            request[configKey][storedKey].nonceCounter += 1;
        }
        return request;
    });
    axiosInstance.interceptors.response.use(null, async (error) => {
        const { config } = error;
        if (config && config[configKey] && config[configKey][storedKey] && error.config[configKey][storedKey].nonceCounter === 1) {
            return Promise.reject(error);
        }
        if (!config[configKey]) {
            config[configKey] = {};
        }
        const message = error.response.headers['www-authenticate'];
        config[configKey][storedKey] = {
            nonce: (0, swish_node_digest_auth_1.getNonceFromMessageString)(message),
            realm: (0, swish_node_digest_auth_1.getRealmFromMessageString)(message),
            cnonce: (0, swish_node_digest_auth_1.generateClientNonce)(),
            nonceCounter: 1,
            qop: 'auth',
        };
        return Promise.resolve(axiosInstance(error.config));
    });
    return axiosInstance;
};
exports.httpDigestAuth = httpDigestAuth;
//# sourceMappingURL=AxiosHttpDigest.js.map